@@ -1,8 +1,9 @@
 import uuid
 import pandas
+from .api_dto import ApiDto
 
 
-class DSDataFrame:
+class DSDataFrame(ApiDto):
 
     def __init__(self, df_id=None):
         if df_id is None:
@@ -12,17 +13,24 @@ class DSDataFrame:
         self.generatedById = None
         self.dataframe = None
 
-    def from_json(self, json):
+    def api_id(self) -> str:
+        return str(self.df_id).upper()
 
+    def endpoint(self) -> str:
+        return "Dataframes"
+
+    def from_json(self, json, api=False):
         if "id" in json.keys():
             self.df_id = uuid.UUID(json["id"])
 
         if "generatedById" in json.keys():
             self.generatedById = json["generatedById"]
 
-    def to_json(self):
+    def to_json(self, api=False):
         obj = {
             "id": str(self.df_id)
         }
         if self.generatedById is not None:
-            obj["generatedById"] = self.generatedById
+            obj["generatedById"] = str(self.generatedById)
+        return obj
+
