@@ -5,7 +5,7 @@ from .mlmodel import MLModel
 class ModelToolkit:
 
     @classmethod
-    def predict(cls, df: pandas.DataFrame, ml_model: MLModel):
+    def predict(cls, df: pandas.DataFrame, ml_model: MLModel, mapping_table=None):
         if ml_model is None or ml_model.trained_model is None or ml_model.input_columns is None:
             raise ValueError("Please download your model from DS API before using it.")
         old_index = df.index
