@@ -1,8 +1,10 @@
 import uuid
 import dill
+import types
+from .api_dto import ApiDto
 
 
-class Script:
+class Script(ApiDto):
 
     def __init__(self, script_id=None):
 
@@ -26,7 +28,13 @@ class Script:
         # Function properties (code)
         self.function = None
 
-    def to_json(self):
+    def api_id(self) -> str:
+        return str(self.script_id).upper()
+
+    def endpoint(self) -> str:
+        return "Scripts"
+
+    def to_json(self, api=False):
         return {
             "id": str(self.script_id),
             "name": str(self.name),
@@ -41,7 +49,7 @@ class Script:
             "outputColumns": list(self.outputColumns)
         }
 
-    def from_json(self, json):
+    def from_json(self, json, api=False):
         if "id" in json.keys():
             self.script_id = uuid.UUID(json["id"])
         if "name" in json.keys():
@@ -69,8 +77,19 @@ class Script:
         self.function = Function()
         self.function.code = myfunction.__code__
 
+        f_globals = myfunction.__globals__
+        self.function.globals = []
+        for k_global in f_globals:
+            if isinstance(myfunction.__globals__[k_global], types.ModuleType):
+                module = f_globals[k_global]
+                self.function.globals.append({
+                    "var": k_global,
+                    "module": str(module.__name__)
+                })
+
 
 class Function:
 
     def __init__(self):
         self.code = None
+        self.globals = None
