@@ -15,6 +15,7 @@ from .script import Script
 from .execution import Execution
 from .dataframe_toolkit import DataFrameToolkit
 from .dsapi_json_encoder import DSAPIEncoder
+from .ds_dataframe import DSDataFrame
 
 
 class WizataDSAPIClient:
@@ -69,7 +70,7 @@ class WizataDSAPIClient:
         """
         lists all elements of a specific entity.
 
-        :param str_type: plural name of the entity (e.g. scripts, plots, mlmodels, ...)
+        :param str_type: plural name of the entity (e.g. scripts, plots, mlmodels, dataframes...)
         :return: list of all elements with at least the id property.
         """
         if str_type == "scripts":
@@ -109,6 +110,19 @@ class WizataDSAPIClient:
                 return ml_models
             else:
                 raise self.__raise_error(response)
+        elif str_type == "dataframes":
+            response = requests.request("GET",
+                                        self.__url() + "dataframes/",
+                                        headers=self.__header()
+                                        )
+            if response.status_code == 200:
+                json_dfs = response.json()
+                dfs = []
+                for json_model in json_dfs:
+                    dfs.append(DSDataFrame(uuid.UUID(json_model["id"])))
+                return dfs
+            else:
+                raise self.__raise_error(response)
         else:
             raise TypeError("Type not supported.")
 
@@ -145,10 +159,20 @@ class WizataDSAPIClient:
                                         headers=self.__header()
                                         )
             if response.status_code == 200:
-                obj.figure = response.json()
+                obj.from_json(response.json())
                 return obj
             else:
                 raise self.__raise_error(response)
+        elif isinstance(obj, DSDataFrame):
+            response = requests.request("GET",
+                                        self.__url() + "dataframes/" + str(obj.df_id) + "/",
+                                        headers=self.__header()
+                                        )
+            if response.status_code == 200:
+                df_bytes = response.content
+                return pickle.loads(df_bytes)
+            else:
+                raise self.__raise_error(response)
         else:
             raise TypeError("Type not supported.")
 
@@ -219,6 +243,13 @@ class WizataDSAPIClient:
                 return
             else:
                 raise self.__raise_error(response)
+        elif isinstance(obj, DSDataFrame):
+            response = requests.delete(self.__url() + "dataframes" + "/" + str(obj.df_id) + "/",
+                                       headers=self.__header())
+            if response.status_code == 200:
+                return
+            else:
+                raise self.__raise_error(response)
         else:
             raise TypeError("Type not supported.")
 
